unit MiscStr;

{************************************************************************
*                                                                       *
*                     Miscellaneous String Routines                     *
*                   Copyright (C) 1998, John Zaitseff                   *
*                                                                       *
************************************************************************}

{ Author:    John Zaitseff <J.Zaitseff@unsw.edu.au>
  Date:      10th April, 1998.
  Version:   1.0

  This unit provides various routines for manipulating strings.

  This file is supplied as part of an application under the GNU General
  Public License.  Hence this file also falls under the same license.
}


{$IFNDEF WIN32}
Error: 'Compile under Borland Delphi for Win32 only (v2 or later).'
{$ENDIF}

{$IFNDEF OPTDEBUG}
{$UNDEF DEBUG}
{$ENDIF}

{$IFDEF DEBUG}
    {$B-,D+,I+,J-,L+,O+,P-,Q+,R+,T+,U+,V+,X+,Y+,Z1}
    {$WARNINGS ON}
    {$HINTS ON}
{$ELSE}
    {$B-,D-,I+,J-,L-,O+,P-,Q-,R-,T+,U+,V+,X+,Y-,Z1}
    {$WARNINGS ON}
    {$HINTS ON}
{$ENDIF}


interface


function RepChar (C : char; Count : integer) : string;
  { Return a string of length Count, in which each character is C }

function BoolStr (Cond : boolean; const TrueStr, FalseStr : string) : string;
  { Return TrueStr if Cond is True, else return FalseStr }

function StrToHex (const S : string) : string;
  { Return a string of space-separated hex digits, one for each character in
    S.  For example, if S = 'AB', return '41 42' }

function TailStr (const S : string; N : integer) : string;
  { Return a string that has the first N characters deleted from S }


implementation


uses
  SysUtils;


{***********************************************************************}
{ Return a string of length Count, in which each character is C }
function RepChar (C : char; Count : integer) : string;

begin
  Result := '';
  if Count < 1 then
    exit;

  SetLength(Result, Count);
  FillChar(Result[1], Count, C)
end;


{***********************************************************************}
{ Return TrueStr if Cond is True, else return FalseStr }
function BoolStr (Cond : boolean; const TrueStr, FalseStr : string) : string;

begin
  if Cond then
    Result := TrueStr
  else
    Result := FalseStr
end;


{***********************************************************************}
{ Return a string of space-separated hex digits, one for each character
  in S.  For example, if S = 'AB', return '41 42' }
function StrToHex (const S : string) : string;

var
  I : integer;

begin
  Result := '';
  if S = '' then
    exit;

  Result := IntToHex(Ord(S[1]), 2);
  for I := 2 to Length(S) do
    Result := Result + ' ' + IntToHex(Ord(S[I]), 2)
end;


{***********************************************************************}
{ Return a string that has the first N characters deleted from S }
function TailStr (const S : string; N : integer) : string;

begin
  Result := copy(S, N + 1, length(S) - N)
end;

end.
